@@ -8,11 +8,11 @@
 #' @seealso \code{\link{npc}}, \code{\link{nproc}} and \code{\link{plot.nproc}}.
 
 lines.nproc <- function(x, col = "black", ...) {
-
-   lines(x$typeI.u, 1-x$typeII.u, xlab = 'FPR', ylab = 'TPR', type = 'l', col = col)
-  if(x$band == TRUE){
-    lines(x$typeI.u, 1-x$typeII.l, col = col)
-  }
-
+    
+    lines(x$typeI.u, 1 - x$typeII.u, xlab = "FPR", ylab = "TPR", type = "l", col = col)
+    if (x$band == TRUE) {
+        lines(x$typeI.u, 1 - x$typeII.l, col = col)
+    }
+    
 }
 
